# Work in progress!!!
# jdtree
Json decision tree/table library.
A rule engine based on json 
The purpose of this library is to parse a decision tree/table 
created with [jdtree-ui](https://github.com/mattskinosix/jdtree-ui)
And give you the last result node based on requested attributes 


## Multithreading 

All roots start a new thread, for the moment with 10 workers


 
